# automata

Automata is a shell package used for debugging workflow automation.
It contains minimal python and javascript packages with just
enough code to programmatically provide the versions of said
packages. It is not intended to be used for any other purposes.
